@@ -7,11 +7,12 @@ import logging
 
 import urllib
 
+from httpexceptor import HTTP400
+
 from tiddlyweb.control import readable_tiddlers_by_bag
 from tiddlyweb.model.collections import Tiddlers
 from tiddlyweb.store import StoreMethodNotImplemented, StoreError
 from tiddlyweb.web.sendtiddlers import send_tiddlers
-from tiddlyweb.web.http import HTTP400
 
 
 def get_search_query(environ):
